stringtools.is_space_delimited_lowercase_string
===============================================

.. autofunction:: abjad.tools.stringtools.is_space_delimited_lowercase_string.is_space_delimited_lowercase_string
